@@ -1,3 +1,6 @@
+from pkgutil import extend_path
+__path__ = extend_path(__path__, __name__)
+
 import abc
 import builtins
 import datetime
@@ -16,7 +19,7 @@ import aws_cdk.aws_redshift_alpha._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@cdklabs/cdk-appflow", "0.0.32", __name__[0:-6], "cdk-appflow@0.0.32.jsii.tgz"
+    "@cdklabs/cdk-appflow", "0.0.36", __name__[0:-6], "cdk-appflow@0.0.36.jsii.tgz"
 )
 
 __all__ = [
